@@ -14,6 +14,6 @@ echo -e '#!/bin/bash\n$1\n"$@"' > $2/ijulia_wrapper.sh
 chmod +x $2/ijulia_wrapper.sh
 
 # kernel settings
-KERNEL_LANGUAGE=julia
-KERNEL_CMD=$2/ijulia_wrapper.sh julia -i --color=yes --project=$2 $3/packages/IJulia/AQu2H/src/kernel.jl {connection_file}
-KERNEL_ENVIRONMENT=$4
\ No newline at end of file
+LANGUAGE=julia
+ARGV=$2/ijulia_wrapper.sh julia -i --color=yes --project=$2 $3/packages/IJulia/AQu2H/src/kernel.jl {connection_file}
+ENV=$4,JULIA_DEPOT_PATH=$3
\ No newline at end of file
